<?php

namespace Drupal\h5p_challenge_rest\Plugin\rest\resource;

use Drupal\rest\ModifiedResourceResponse;
use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;
use Drupal\h5p_challenge\FetchClass\H5PChallengePoints;

/**
 * Provides a resource to get view modes by entity and bundle.
 *
 * @RestResource(
 *   id = "h5p_challenge_challenge_results_resource",
 *   label = @Translation("Challenge results"),
 *   uri_paths = {
 *     "canonical" = "api/h5p_challenge/challenge/{uuid}/results"
 *   }
 * )
 */
class ChallengeResults extends ResourceBase {

  /**
   * A current user instance.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Database connection instance.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->logger = $container->get('logger.factory')->get('h5p_challenge_rest');
    $instance->currentUser = $container->get('current_user');
    $instance->database = $container->get('database');
    return $instance;
  }

    /**
     * Responds to GET requests.
     *
     * @param string $payload
     *
     * @return \Drupal\rest\ResourceResponse
     *   The HTTP response object.
     *
     * @throws \Symfony\Component\HttpKernel\Exception\HttpException
     *   Throws exception expected.
     */
    public function get(string $uuid) {
      $query = $this->database->select('h5p_challenge_points', 'cp', [
        'fetch' => H5PChallengePoints::class,
      ]);
      $query->fields('cp');
      $query->condition('cp.challenge_uuid', $uuid, '=');
      $query->orderBy('cp.started', 'DESC');

      $responses = $query->execute()->fetchAll();

      $data['responses'] = $responses;

      $response = new ResourceResponse($data, 200);

      // TODO See if setting it non-cacheable is a better approach, see URL for details
      // https://drupal.stackexchange.com/a/224508/92770
      $response->addCacheableDependency($data);

      return $response;
    }

}
